.. _api:

Here you can find exact details regarding user interfaces.

Main Interface
==============

This is the entry point ot the application.

.. _run:

.. autofunction:: main.run

.. click:: app.cli:cli
   :prog: cli
   :nested: full
